// This file is part of the Xillybus project.

`timescale 1ns / 10ps

module xillybus
  (
   output ddr_memory_we_n,
   output ddr_memory_ras_n,
   output ddr_memory_odt,
   inout [0:0] ddr_memory_dqs_n,
   inout [0:0] ddr_memory_dqs,
   inout [7:0] ddr_memory_dq,
   output [0:0] ddr_memory_dm,
   output ddr_memory_ddr3_rst,
   output ddr_memory_cs_n,
   output ddr_memory_clk_n,
   output ddr_memory_clk,
   output ddr_memory_cke,
   output ddr_memory_cas_n,
   output [2:0] ddr_memory_ba,
   output [12:0] ddr_memory_addr,
   output SysACE_WEN,
   output SysACE_OEN,
   input SysACE_MPIRQ,
   inout [7:0] SysACE_MPD,
   output [6:0] SysACE_MPA,
   input SysACE_CLK,
   output SysACE_CEN,
   output RS232_Uart_1_sout,
   input RS232_Uart_1_sin,
   input RESET,
   input [0:4] Push_Buttons_5Bits_TRI_I,
   output Linear_Flash_we_n,
   output Linear_Flash_oe_n,
   inout [0:15] Linear_Flash_data,
   output Linear_Flash_ce_n,
   output [0:23] Linear_Flash_address,
   output [0:4] LEDs_Positions_TRI_O,
   output [0:7] LEDs_8Bits_TRI_O,
   inout IIC_SFP_SDA,
   inout IIC_SFP_SCL,
   inout IIC_FMC_SDA,
   inout IIC_FMC_SCL,
   inout IIC_EEPROM_SDA,
   inout IIC_EEPROM_SCL,
   inout IIC_DVI_SDA,
   inout IIC_DVI_SCL,
   output Ethernet_Lite_TX_EN,
   input Ethernet_Lite_TX_CLK,
   output [3:0] Ethernet_Lite_TXD,
   input Ethernet_Lite_RX_ER,
   input Ethernet_Lite_RX_DV,
   input Ethernet_Lite_RX_CLK,
   input [3:0] Ethernet_Lite_RXD,
   output Ethernet_Lite_PHY_RST_N,
   inout Ethernet_Lite_MDIO,
   output Ethernet_Lite_MDC,
   input Ethernet_Lite_CRS,
   input Ethernet_Lite_COL,
   input [0:7] DIP_Switches_8Bits_TRI_I,
   input CLK_P,
   input CLK_N,
 
   input [31:0] user_r_read_32_data,
   input 	user_r_read_32_empty,
   input 	user_r_read_32_eof,
   input 	user_w_write_32_full,
   input [7:0] 	user_r_read_8_data,
   input 	user_r_read_8_empty,
   input 	user_r_read_8_eof,
   input 	user_w_write_8_full,
   input [7:0] 	user_r_mem_8_data,
   input 	user_r_mem_8_empty,
   input 	user_r_mem_8_eof,
   input 	user_w_mem_8_full,
   output [3:0] GPIO_LED,
   output 	quiesce,
   output 	bus_clk,
   output 	user_r_read_32_rden,
   output 	user_r_read_32_open,
   output 	user_w_write_32_wren,
   output [31:0] user_w_write_32_data,
   output 	 user_w_write_32_open,
   output 	 user_r_read_8_rden,
   output 	 user_r_read_8_open,
   output 	 user_w_write_8_wren,
   output [7:0]  user_w_write_8_data,
   output 	 user_w_write_8_open,
   output 	 user_r_mem_8_rden,
   output 	 user_r_mem_8_open,
   output 	 user_w_mem_8_wren,
   output [7:0]  user_w_mem_8_data,
   output 	 user_w_mem_8_open,
   output [4:0]  user_mem_8_addr,
   output 	 user_mem_8_addr_update
   );
   
  wire  bus_rst_n;
  wire [31:0] S_AXI_AWADDR;
  wire  S_AXI_AWVALID;
  wire [31:0] S_AXI_WDATA;
  wire [3:0] S_AXI_WSTRB;
  wire  S_AXI_WVALID;
  wire  S_AXI_BREADY;
  wire [31:0] S_AXI_ARADDR;
  wire  S_AXI_ARVALID;
  wire  S_AXI_RREADY;
  wire  S_AXI_ARREADY;
  wire [31:0] S_AXI_RDATA;
  wire [1:0] S_AXI_RRESP;
  wire  S_AXI_RVALID;
  wire  S_AXI_WREADY;
  wire [1:0] S_AXI_BRESP;
  wire  S_AXI_BVALID;
  wire  S_AXI_AWREADY;
  wire  M_AXI_ARREADY;
  wire  M_AXI_ARVALID;
  wire [31:0] M_AXI_ARADDR;
  wire [7:0] M_AXI_ARLEN;
  wire [2:0] M_AXI_ARSIZE;
  wire [1:0] M_AXI_ARBURST;
  wire [2:0] M_AXI_ARPROT;
  wire [3:0] M_AXI_ARCACHE;
  wire  M_AXI_RREADY;
  wire  M_AXI_RVALID;
  wire [31:0] M_AXI_RDATA;
  wire [1:0] M_AXI_RRESP;
  wire  M_AXI_RLAST;
  wire  M_AXI_AWREADY;
  wire  M_AXI_AWVALID;
  wire [31:0] M_AXI_AWADDR;
  wire [7:0] M_AXI_AWLEN;
  wire [2:0] M_AXI_AWSIZE;
  wire [1:0] M_AXI_AWBURST;
  wire [2:0] M_AXI_AWPROT;
  wire [3:0] M_AXI_AWCACHE;
  wire  M_AXI_WREADY;
  wire  M_AXI_WVALID;
  wire [31:0] M_AXI_WDATA;
  wire [3:0] M_AXI_WSTRB;
  wire  M_AXI_WLAST;
  wire  M_AXI_BREADY;
  wire  M_AXI_BVALID;
  wire [1:0] M_AXI_BRESP;
  wire  host_interrupt;

   system system_i 
     (
      .ddr_memory_we_n ( ddr_memory_we_n ),
      .ddr_memory_ras_n ( ddr_memory_ras_n ),
      .ddr_memory_odt ( ddr_memory_odt ),
      .ddr_memory_dqs_n ( ddr_memory_dqs_n[0:0] ),
      .ddr_memory_dqs ( ddr_memory_dqs[0:0] ),
      .ddr_memory_dq ( ddr_memory_dq ),
      .ddr_memory_dm ( ddr_memory_dm[0:0] ),
      .ddr_memory_ddr3_rst ( ddr_memory_ddr3_rst ),
      .ddr_memory_cs_n ( ddr_memory_cs_n ),
      .ddr_memory_clk_n ( ddr_memory_clk_n ),
      .ddr_memory_clk ( ddr_memory_clk ),
      .ddr_memory_cke ( ddr_memory_cke ),
      .ddr_memory_cas_n ( ddr_memory_cas_n ),
      .ddr_memory_ba ( ddr_memory_ba ),
      .ddr_memory_addr ( ddr_memory_addr ),
      .SysACE_WEN ( SysACE_WEN ),
      .SysACE_OEN ( SysACE_OEN ),
      .SysACE_MPIRQ ( SysACE_MPIRQ ),
      .SysACE_MPD ( SysACE_MPD ),
      .SysACE_MPA ( SysACE_MPA ),
      .SysACE_CLK ( SysACE_CLK ),
      .SysACE_CEN ( SysACE_CEN ),
      .RS232_Uart_1_sout ( RS232_Uart_1_sout ),
      .RS232_Uart_1_sin ( RS232_Uart_1_sin ),
      .RESET ( RESET ),
      .Push_Buttons_5Bits_TRI_I ( Push_Buttons_5Bits_TRI_I ),
      .Linear_Flash_we_n ( Linear_Flash_we_n ),
      .Linear_Flash_oe_n ( Linear_Flash_oe_n ),
      .Linear_Flash_data ( Linear_Flash_data ),
      .Linear_Flash_ce_n ( Linear_Flash_ce_n ),
      .Linear_Flash_address ( Linear_Flash_address ),
      .LEDs_Positions_TRI_O ( LEDs_Positions_TRI_O ),
      .LEDs_8Bits_TRI_O ( LEDs_8Bits_TRI_O ),
      .IIC_SFP_SDA ( IIC_SFP_SDA ),
      .IIC_SFP_SCL ( IIC_SFP_SCL ),
      .IIC_FMC_SDA ( IIC_FMC_SDA ),
      .IIC_FMC_SCL ( IIC_FMC_SCL ),
      .IIC_EEPROM_SDA ( IIC_EEPROM_SDA ),
      .IIC_EEPROM_SCL ( IIC_EEPROM_SCL ),
      .IIC_DVI_SDA ( IIC_DVI_SDA ),
      .IIC_DVI_SCL ( IIC_DVI_SCL ),
      .Ethernet_Lite_TX_EN ( Ethernet_Lite_TX_EN ),
      .Ethernet_Lite_TX_CLK ( Ethernet_Lite_TX_CLK ),
      .Ethernet_Lite_TXD ( Ethernet_Lite_TXD ),
      .Ethernet_Lite_RX_ER ( Ethernet_Lite_RX_ER ),
      .Ethernet_Lite_RX_DV ( Ethernet_Lite_RX_DV ),
      .Ethernet_Lite_RX_CLK ( Ethernet_Lite_RX_CLK ),
      .Ethernet_Lite_RXD ( Ethernet_Lite_RXD ),
      .Ethernet_Lite_PHY_RST_N ( Ethernet_Lite_PHY_RST_N ),
      .Ethernet_Lite_MDIO ( Ethernet_Lite_MDIO ),
      .Ethernet_Lite_MDC ( Ethernet_Lite_MDC ),
      .Ethernet_Lite_CRS ( Ethernet_Lite_CRS ),
      .Ethernet_Lite_COL ( Ethernet_Lite_COL ),
      .DIP_Switches_8Bits_TRI_I ( DIP_Switches_8Bits_TRI_I ),
      .CLK_P ( CLK_P ),
      .CLK_N ( CLK_N ),
      .xillybus_bus_clk (bus_clk ),
      .xillybus_bus_rst_n (bus_rst_n ),
      .xillybus_S_AXI_AWADDR (S_AXI_AWADDR ),
      .xillybus_S_AXI_AWVALID (S_AXI_AWVALID ),
      .xillybus_S_AXI_WDATA (S_AXI_WDATA ),
      .xillybus_S_AXI_WSTRB (S_AXI_WSTRB ),
      .xillybus_S_AXI_WVALID (S_AXI_WVALID ),
      .xillybus_S_AXI_BREADY (S_AXI_BREADY ),
      .xillybus_S_AXI_ARADDR (S_AXI_ARADDR ),
      .xillybus_S_AXI_ARVALID (S_AXI_ARVALID ),
      .xillybus_S_AXI_RREADY (S_AXI_RREADY ),
      .xillybus_S_AXI_ARREADY (S_AXI_ARREADY ),
      .xillybus_S_AXI_RDATA (S_AXI_RDATA ),
      .xillybus_S_AXI_RRESP (S_AXI_RRESP ),
      .xillybus_S_AXI_RVALID (S_AXI_RVALID ),
      .xillybus_S_AXI_WREADY (S_AXI_WREADY ),
      .xillybus_S_AXI_BRESP (S_AXI_BRESP ),
      .xillybus_S_AXI_BVALID (S_AXI_BVALID ),
      .xillybus_S_AXI_AWREADY (S_AXI_AWREADY ),
      .xillybus_M_AXI_ARREADY (M_AXI_ARREADY ),
      .xillybus_M_AXI_ARVALID (M_AXI_ARVALID ),
      .xillybus_M_AXI_ARADDR (M_AXI_ARADDR ),
      .xillybus_M_AXI_ARLEN (M_AXI_ARLEN ),
      .xillybus_M_AXI_ARSIZE (M_AXI_ARSIZE ),
      .xillybus_M_AXI_ARBURST (M_AXI_ARBURST ),
      .xillybus_M_AXI_ARPROT (M_AXI_ARPROT ),
      .xillybus_M_AXI_ARCACHE (M_AXI_ARCACHE ),
      .xillybus_M_AXI_RREADY (M_AXI_RREADY ),
      .xillybus_M_AXI_RVALID (M_AXI_RVALID ),
      .xillybus_M_AXI_RDATA (M_AXI_RDATA ),
      .xillybus_M_AXI_RRESP (M_AXI_RRESP ),
      .xillybus_M_AXI_RLAST (M_AXI_RLAST ),
      .xillybus_M_AXI_AWREADY (M_AXI_AWREADY ),
      .xillybus_M_AXI_AWVALID (M_AXI_AWVALID ),
      .xillybus_M_AXI_AWADDR (M_AXI_AWADDR ),
      .xillybus_M_AXI_AWLEN (M_AXI_AWLEN ),
      .xillybus_M_AXI_AWSIZE (M_AXI_AWSIZE ),
      .xillybus_M_AXI_AWBURST (M_AXI_AWBURST ),
      .xillybus_M_AXI_AWPROT (M_AXI_AWPROT ),
      .xillybus_M_AXI_AWCACHE (M_AXI_AWCACHE ),
      .xillybus_M_AXI_WREADY (M_AXI_WREADY ),
      .xillybus_M_AXI_WVALID (M_AXI_WVALID ),
      .xillybus_M_AXI_WDATA (M_AXI_WDATA ),
      .xillybus_M_AXI_WSTRB (M_AXI_WSTRB ),
      .xillybus_M_AXI_WLAST (M_AXI_WLAST ),
      .xillybus_M_AXI_BREADY (M_AXI_BREADY ),
      .xillybus_M_AXI_BVALID (M_AXI_BVALID ),
      .xillybus_M_AXI_BRESP (M_AXI_BRESP ),
      .xillybus_host_interrupt (host_interrupt )
      );

  xillybus_core  xillybus_core_ins(.M_AXI_WVALID_w(M_AXI_WVALID),
    .M_AXI_WDATA_w(M_AXI_WDATA), .M_AXI_WSTRB_w(M_AXI_WSTRB),
    .M_AXI_WLAST_w(M_AXI_WLAST), .M_AXI_BREADY_w(M_AXI_BREADY),
    .M_AXI_BVALID_w(M_AXI_BVALID), .M_AXI_BRESP_w(M_AXI_BRESP),
    .host_interrupt_w(host_interrupt), .GPIO_LED_w(GPIO_LED),
    .quiesce_w(quiesce), .user_r_read_32_rden_w(user_r_read_32_rden),
    .user_r_read_32_data_w(user_r_read_32_data), .user_r_read_32_empty_w(user_r_read_32_empty),
    .user_r_read_32_eof_w(user_r_read_32_eof), .user_r_read_32_open_w(user_r_read_32_open),
    .user_w_write_32_wren_w(user_w_write_32_wren),
    .user_w_write_32_data_w(user_w_write_32_data),
    .user_w_write_32_full_w(user_w_write_32_full),
    .user_w_write_32_open_w(user_w_write_32_open),
    .user_r_read_8_rden_w(user_r_read_8_rden), .user_r_read_8_data_w(user_r_read_8_data),
    .user_r_read_8_empty_w(user_r_read_8_empty), .user_r_read_8_eof_w(user_r_read_8_eof),
    .bus_clk_w(bus_clk), .user_r_read_8_open_w(user_r_read_8_open),
    .bus_rst_n_w(bus_rst_n), .S_AXI_AWADDR_w(S_AXI_AWADDR),
    .S_AXI_AWVALID_w(S_AXI_AWVALID), .S_AXI_WDATA_w(S_AXI_WDATA),
    .S_AXI_WSTRB_w(S_AXI_WSTRB), .user_w_write_8_wren_w(user_w_write_8_wren),
    .S_AXI_WVALID_w(S_AXI_WVALID), .user_w_write_8_data_w(user_w_write_8_data),
    .user_w_write_8_full_w(user_w_write_8_full), .user_w_write_8_open_w(user_w_write_8_open),
    .S_AXI_BREADY_w(S_AXI_BREADY), .S_AXI_ARADDR_w(S_AXI_ARADDR),
    .S_AXI_ARVALID_w(S_AXI_ARVALID), .S_AXI_RREADY_w(S_AXI_RREADY),
    .user_r_mem_8_rden_w(user_r_mem_8_rden), .user_r_mem_8_data_w(user_r_mem_8_data),
    .user_r_mem_8_empty_w(user_r_mem_8_empty), .user_r_mem_8_eof_w(user_r_mem_8_eof),
    .user_r_mem_8_open_w(user_r_mem_8_open), .S_AXI_ARREADY_w(S_AXI_ARREADY),
    .S_AXI_RDATA_w(S_AXI_RDATA), .S_AXI_RRESP_w(S_AXI_RRESP),
    .S_AXI_RVALID_w(S_AXI_RVALID), .S_AXI_WREADY_w(S_AXI_WREADY),
    .S_AXI_BRESP_w(S_AXI_BRESP), .user_w_mem_8_wren_w(user_w_mem_8_wren),
    .user_w_mem_8_data_w(user_w_mem_8_data), .user_w_mem_8_full_w(user_w_mem_8_full),
    .user_w_mem_8_open_w(user_w_mem_8_open), .S_AXI_BVALID_w(S_AXI_BVALID),
    .S_AXI_AWREADY_w(S_AXI_AWREADY), .M_AXI_ARREADY_w(M_AXI_ARREADY),
    .M_AXI_ARVALID_w(M_AXI_ARVALID), .user_mem_8_addr_w(user_mem_8_addr),
    .M_AXI_ARADDR_w(M_AXI_ARADDR), .user_mem_8_addr_update_w(user_mem_8_addr_update),
    .M_AXI_ARLEN_w(M_AXI_ARLEN), .M_AXI_ARSIZE_w(M_AXI_ARSIZE),
    .M_AXI_ARBURST_w(M_AXI_ARBURST), .M_AXI_ARPROT_w(M_AXI_ARPROT),
    .M_AXI_ARCACHE_w(M_AXI_ARCACHE), .M_AXI_RREADY_w(M_AXI_RREADY),
    .M_AXI_RVALID_w(M_AXI_RVALID), .M_AXI_RDATA_w(M_AXI_RDATA),
    .M_AXI_RRESP_w(M_AXI_RRESP), .M_AXI_RLAST_w(M_AXI_RLAST),
    .M_AXI_AWREADY_w(M_AXI_AWREADY), .M_AXI_AWVALID_w(M_AXI_AWVALID),
    .M_AXI_AWADDR_w(M_AXI_AWADDR), .M_AXI_AWLEN_w(M_AXI_AWLEN),
    .M_AXI_AWSIZE_w(M_AXI_AWSIZE), .M_AXI_AWBURST_w(M_AXI_AWBURST),
    .M_AXI_AWPROT_w(M_AXI_AWPROT), .M_AXI_AWCACHE_w(M_AXI_AWCACHE),
    .M_AXI_WREADY_w(M_AXI_WREADY));

endmodule
